@@ -238,7 +238,10 @@ class TextFormatter(BaseFormatter):
                 to_append = [word]
             else:
                 change_list[word] = " ".join(
-                    [x.upper() if self.return_upper_case else x for x in to_append]
+                    [
+                        x.upper() if self.return_upper_case else x
+                        for x in filter(len, to_append)
+                    ]
                 )
 
             word_list += to_append
